===============================================================
qirest-client: Quantitative Imaging Profile REST client
===============================================================

qiprofile <http://github.com/ohsu-qin/qiprofile/blob/master/doc/index.rst#quantitative-imaging-profile/>`_
REST API.
See the `documentation <http://qiprofile-rest-client.readthedocs.org/en/latest/>`_
for more information.
